.. qiitareactioncounter documentation master file, created by
   sphinx-quickstart on Wed Mar 26 13:22:51 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

|project| documentation
==================================


バージョン: |version|

主な機能
--------

- ARPAbet音素記号をカタカナに変換

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
